@@ -48,8 +48,8 @@ class Generator:
     @staticmethod
     def _validate_cloud(cloud=None):
         if cloud:
-            cloud_type = cloud.pop("type")
             try:
+                cloud_type = cloud.get("type")
                 cloud_dataclass = cloud_map[cloud_type]
                 return cloud_dataclass(**cloud)
             except Exception as e:
